@@ -2,7 +2,7 @@
 use v5.14;
 use warnings;
 
-package Test::BDD::Cucumber::Executor 0.85;
+package Test::BDD::Cucumber::Executor 0.87;
 
 =head1 NAME
 
@@ -10,7 +10,7 @@ Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.85
+version 0.87
 
 =head1 DESCRIPTION
 
@@ -248,13 +248,18 @@ sub execute_outline {
                     dataset => {},
                 });
         }
+        $harness->scenario_skip( $outline, {} );
 
         return;
     }
 
     if ($tagspec) {
         @datasets = _match_tags( $tagspec, @datasets );
-        return unless @datasets;
+
+        unless (@datasets) {
+            $harness->scenario_skip( $outline, {} );
+            return;
+        }
     }
 
 
