@@ -1,7 +1,7 @@
 use v5.14;
 use warnings;
 
-package Test::BDD::Cucumber::Harness::JSON 0.85;
+package Test::BDD::Cucumber::Harness::JSON 0.87;
 
 =head1 NAME
 
@@ -9,7 +9,7 @@ Test::BDD::Cucumber::Harness::JSON - Generate results to JSON file
 
 =head1 VERSION
 
-version 0.85
+version 0.87
 
 =head1 DESCRIPTION
 
@@ -98,7 +98,7 @@ sub shutdown {
 
 sub format_tags {
     my ( $self, $tags_ref ) = @_;
-    return [ map { { name => '@' . $_ } } @$tags_ref ];
+    return [ map { { name => $_ } } @$tags_ref ];
 }
 
 sub format_description {
