@@ -1,7 +1,7 @@
 use v5.14;
 use warnings;
 
-package Test::BDD::Cucumber::Parser 0.85;
+package Test::BDD::Cucumber::Parser 0.87;
 
 =head1 NAME
 
@@ -9,7 +9,7 @@ Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.85
+version 0.87
 
 =head1 DESCRIPTION
 
@@ -119,7 +119,7 @@ sub _construct_matchers {
         _scenario_line   => qr/^($scenario_line_kw): ?(.*)?/,
         _examples_line   => qr/^($l->{examples}): ?(.+)?$/,
         _table_line      => qr/^\s*\|/,
-        _tags_line       => qr/\@([^\s]+)/,
+        _tags_line       => qr/\@([^\s\@]+)/,
         );
 }
 
@@ -206,7 +206,7 @@ sub _extract_feature_name {
 
             # Feature-level tags
         } elsif ( $line->content =~ m/^\s*\@\w/ ) {
-            my @tags = $line->content =~ m/\@([^\s]+)/g;
+            my @tags = $line->content =~ m/(\@[^\s\@]+)/g;
             push( @feature_tags, @tags );
 
         } else {
@@ -336,7 +336,7 @@ sub _extract_scenarios {
 
             # Scenario-level tags
         } elsif ( $line->content =~ m/^\s*\@\w/ ) {
-            push @tags, ( $line->content =~ m/\@([^\s]+)/g );
+            push @tags, ( $line->content =~ m/(\@[^\s\@]+)/g );
 
         } else {
             die parse_error_from_line( "Malformed scenario line", $line );
